##############################
ConversionDynamic class
##############################

.. |br| raw:: html

   <br />

Extension of the conversion class with a more specific dynamic behavior. It includes ramping constraints, as well as minimum up-time or down-time constraints of the conversion component.

**ConversionDynamic class description:**

.. automodule:: conversionDynamic
.. autoclass:: ConversionDynamic
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: ConversionDynamic
   :parts: 1

|

**ConversionDynamicModel class description:**

.. autoclass:: ConversionDynamicModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: ConversionDynamicModel
   :parts: 1

